package com.engine.organization.mapper.trigger;

import org.apache.ibatis.annotations.Param;

import java.sql.Date;

/**
 * @author:dxfeng
 * @createTime: 2022/09/21
 * @version: 1.0
 */
public interface StaffTriggerMapper {
    //Integer countCompanyUsers(@Param("ecCompanyId") String ecCompanyId);

    //Integer countDepartmentUsers(@Param("ecDepartmentId") String ecDepartmentId);

    //Integer countJobUsers(@Param("jobTitle") String jobTitle);

    Integer countOnJobByJObId(@Param("jobId") String jobId);

    //Integer countAllUsers();

    Integer countCompanyStaffNum(@Param("currentDate") Date currentDate, @Param("companyId") String companyId);

    Integer countDepartmentStaffNum(@Param("currentDate") Date currentDate, @Param("departmentId") String departmentId);

    Integer countJobStaffNum(@Param("currentDate") Date currentDate, @Param("jobId") String jobId);

    Integer updateOrgStaffs(@Param("currentDate") Date currentDate, @Param("fType") String fType, @Param("fObjId") String fObjId, @Param("fPlan") Integer fPlan, @Param("fOnJob") Integer fOnJob);

    String getIdByObjIdAndType(@Param("currentDate") Date currentDate, @Param("fObjId") String fObjId, @Param("fType") String fType);

    Integer sumPlanByParentId(@Param("currentDate") Date currentDate, @Param("parentId") String parentId);

    Integer sumOnJobByParentId(@Param("currentDate") Date currentDate, @Param("parentId") String parentId);
}
